navigator.serviceWorker.register('worker.js');

var DATE_LOCAL = "fr";
var DATE_FORMAT = "dd.mm.yy";
var TODO_STORAGE = new JsonStorage("TODO");
var BOOKMARK_STORAGE = new JsonStorage("BOOKMARK");
var CONFIG_STORAGE = new JsonStorage("CONFIG");
var TODO_TEMPLATE;
var ON_SMARTPHONE; 

$(function (){       
    TODO_TEMPLATE = $(".template_todo").clone().removeClass("template");
    ON_SMARTPHONE = window.matchMedia("(max-width: 41em)"); 
    crossmediaDateField();
    menuHandler();             
    $("#todo_btn_create").on("click", createTodo);
    $("#todoList").on("click", ".todo_btn_delete", deleteTodo); 
    onlineOffline();
    $("#todoList").on("synch", synchTodoStroageAndDom);
    $("#todoList").on("synch", synchTodoStroageAndBackend);
    $("#todoList").trigger("synch");
    $("#hideIntro").on("click", hideIntro)
    $("#header_main").on("click", '.online', function () {
        location.hash = "export";        
    });        
    $("#btnExport").on("click", exportTodo);
    $("#btnImport").on("click", importTodo)
})

function importTodo() {
    var code = $("#exportImportCode").val();
    $.post("backend/import.php", {code: code}, function (tasks) {
        TODO_STORAGE.clear();
        $.each(tasks, function (i, task) {
            TODO_STORAGE.addItem(task);
        })
        $("#todoList").trigger("synch");
    })
}

function exportTodo() {
    var todo = TODO_STORAGE.toJson();
    $.post("backend/export.php", {data: todo}, function (response) {
        $("#exportImportCode").val(response);
    })
    
}

function hideIntro() {
    CONFIG_STORAGE.setItem("hide_intro", true);
    changePage("#todo");
}

function synchTodoStroageAndBackend() {
    console.log("TODO: backup json to webserver !");
}   

function synchTodoStroageAndDom() {   
    $("#todoList").empty();
    var todoList = TODO_STORAGE.toArray();
    todoList.sort(function (t1, t2) {
        var d1 = new Date(t1.item.date);
        var d2 = new Date(t2.item.date);
        if (d1 < d2) return -1;
        if (d1 > d2) return 1;
        return 0;
    });
    $.each(todoList, function (id, todo){
        createTodoDOM(todo.item.name, todo.item.date, todo.key);
    });
}

function createTodoDOM(name, date, id)
{
    date = $.datepicker.formatDate(DATE_FORMAT, new Date(date));
    var todo_dom = TODO_TEMPLATE.clone();    
    todo_dom.find(".todo_text").text(name);
    todo_dom.find(".todo_date").text(date);
    todo_dom.find(".todo_btn_delete").data("id", id);
    $("#todoList").append(todo_dom);
}

function onlineOffline()
{
    $(window).on('online offline', function (event) {
        $("#network_status").removeClass("online offline");
        $("#network_status").addClass(event.type);
    });
    $(window).on('online', function (event) {
        $(".onlineOnly").removeClass("linkDisable");
    });
    $(window).on('offline', function (event) {
        $(".onlineOnly").addClass("linkDisable");
    })    
    $(window).trigger(navigator.onLine ? 'online' : 'offline');
}

function deleteTodo() {
    var id = $(this).data("id");
    TODO_STORAGE.removeItem(id);
    $("#todoList").trigger("synch");      
}

function createTodo() {    
    var name = $("#todo_field_name").val();
    var date = $("#todo_field_date").val(); 
    // Pour le datepicker natif, la date est au format ATOM
    // On la convertit au).leng format français
    if ($("[type='date']").length == 0) {        
        date = $.datepicker.parseDate(DATE_FORMAT, date);
        date = $.datepicker.formatDate($.datepicker.ATOM, new Date(date));
    }
    TODO_STORAGE.addItem({
        name: name,
        date: date
    })        
    $("#todoList").trigger("synch");
}

function menuHandler(){
    $("nav a").on("click", function (event) {
        if ($(this).hasClass("linkDisable")) {
            return false;
        }
        var page = $(this).attr("href");
        history.pushState(null, null, page);
        changePage(page);          
        return false;
    });    
    $(window).on("popstate", function (event) {
        var id = location.hash;
        if ($(id).length == 0) {
            if (CONFIG_STORAGE.getItem("hide_intro")) {
                changePage("#todo");                
            } else {
                changePage("#intro");
            }
        } else {
            changePage(id);
        }                
    });
    $(window).trigger("popstate");
}

function changePage(id) {    
    $(".page").hide();
    $(id).show();
    $("nav a").removeClass("activ");
    $("a[href='" + id + "'").addClass("activ"); 
    // Ne pas scroller vers l'ancre
    setTimeout(function() {
        window.scrollTo(0, 0);
    }, 1);
}

function crossmediaDateField(){    
    // Sur "desktop", utiliser le calendrier jQueryUI plutôt que le type="date"
    if (!ON_SMARTPHONE.matches) { 
        var inputDate = $("[type='date']");        
        inputDate.attr("type", "text");
        var options = $.datepicker.regional[DATE_LOCAL];
        options.dateFormat = DATE_FORMAT;
        inputDate.datepicker(options);
    }
}